``eradiate.radprops``
=====================

.. automodule:: eradiate.radprops

.. py:currentmodule:: eradiate.radprops

.. rubric:: Modules

.. autosummary::
   :recursive:
   :toctree: generated/autosummary/

   absorption
   rayleigh

.. rubric:: Classes

**Factory**: :data:`rad_profile_factory`

.. autosummary::
   :recursive:
   :toctree: generated/autosummary/

   ZGrid
   RadProfile
   AtmosphereRadProfile
